/****************************************************************************/
/**   vjbox  Globale Variablen-Deklaration                                 **/
/**                                                                        **/
/** Copyright (C) 1997 Jochen Tillmann-Sarrazin, DG6VJ                     **/
/** All rights reserved.                                                   **/
/****************************************************************************/


#ifndef __GLOBAL_H__
#define __GLOBAL_H__


#include <stdio.h>
#include <stdlib.h>
#include <sys/time.h>
#include <sys/types.h>
#include <sys/socket.h>
#include <sys/stat.h>
#include <sys/times.h>
#include <netinet/in.h>
#include <dirent.h>
#include <unistd.h>
#include <fcntl.h>
#include <errno.h>
#include <signal.h>
#include <syslog.h>
#include <dirent.h>


#ifndef FALSE
  #define FALSE 0
#endif
#ifndef TRUE
  #define TRUE 1
#endif

#define MAJORLEVEL 0
#define MINORLEVEL 8
#define PATCHLEVEL 0
#define DATUM "27.05.99"

#define MAXLISTEN 200

typedef unsigned char uchar;

#define UDATA_SYSOP 1		/* Der User hat sich als SysOp eingeloggt. */
#define UDATA_PASSWD 2		/* Hat sich der User mit einem Passwort ausgewiesen? */
#define UDATA_SF 4		/* Die Station hat sich als S&F-Station augewiesen */

/* User-Data-Struktur im Speicher */
typedef struct {
  char call[9];
  char mybbs[15];
  char name[21];
  time_t lastlogin;
  time_t lastquit;
  time_t lastmybbs;
  int readlock;
  long anzsend;
  long anzrec;
  long anzread;
  long anzlogins;
  char friends[100];
  int flags;
  char passwd[81];
  char expect_pw[100];
  uint level;			/* Mgliche Level:
                                 *    9: Stn darf sich als SysOp einloggen
                                 *    8: Stn darf sich als S&F-Stn einloggen
                                 */
} s_udata;


typedef unsigned char BYTE;

/* struct fr die Berechnung der Zeit-Differenz */
struct tm_diff {
  int days;
  BYTE hours;
  BYTE mins;
  BYTE secs;
};


/* Informationen ber uns, also ber die Mailbox */
#define MY_THIRDPARTY 1		/* Third-Party-Mail annehmen? */
 extern  char mycall[10];
 extern  char myhierarch[50];
 extern  char boxroot[200];
 extern  char sfinfo[21];
 extern  unsigned short int boxport;
 extern  int stdlt;			/* Standard-Lifetime fr unbekannte Rubriken */
 extern  int userlt;			/* Lifetime fr Usermails */
 extern  time_t startuptime;
 extern  unsigned int myflags;		/* Lokale Flags (siehe MY_XXX) */
 extern  int bidfifofd;


/* In diesem Format wird das File boards.box als verkettete Liste im Speicher abgelegt. */
typedef struct s_boards {
  struct s_boards *next;	/* Zeiger auf den nchsten Listeneintrag */
  char rubrik[9];		/* Rubrikenname vor dem Transfer */
  char rubrik_after[9];		/* Rubrikenname nach dem Transfer */
  int lifetime;			/* Zugehrige Lifetime */
  int lifetime_max;		/* Maximal zulssige Lifetime */
} s_boards;

/* Hier wird das File reject.box als verkette Liste abgespeichert */
typedef struct s_reject {
  struct s_reject *next;	/* Zeiger auf den nchsten Listeneintrag */
  int was;			/* 1 = Reject, 2 = Hold, 3 = Hold wenn lokal, 4 = Hold wenn lokal und ohne passwort */
  int typ;			/* Typ der Mail - 1 = Bulletin, 2 = Usermail */
  char absender[9];
  char verteiler[9];
  char empfaenger[9];
  int maxsize;			/* Maximale Gre - 0 = unendlich */
} s_reject;

typedef struct s_server {
  struct s_server *next;
  char rub[9];			/* Fr welche Rubrik? */
  char *filename;		/* Dateiname des Servers */
} s_server;

/* Informationen ber den User, der im Augenblick auf diesem Prozess eingeloggt ist. */
extern int child_fd;
extern s_udata child_udata;
extern int logged_in;
 extern  char aktbox[9];			/* Aktuelles Userfile */
extern int aktbox_readlock;		/* Readlock-Eintrag der aktuellen Mailbox */
 extern  double clktck;

/* Wurzel-Eintrag fr die transfer/lifetime-Liste (boards.box) */
 extern  s_boards *boardsroot;
/* Wurzel-Eintrag fr die reject.box-Liste */
 extern  s_reject *rejectroot;
/* Wurzel-Eintrag fr die server.box-Liste */
 extern  s_server *serverroot;


/* Flags fr Check- und Index-Files */
#define MAIL_DEL 1              /* Mail has  been erased */
#define MAIL_READ 2             /* Mail has been read */
#define MAIL_USER 4		/* Ist die Mail eine Usermail? */
#define MAIL_HOLD 8             /* Mail has been hold */
#define MAIL_REMOTE 16          /* Mailbody is not local */
#define MAIL_OUTSTANDING 32     /* Mail has to be forwarded yet */

/* Format des Check-Files. Wird unter anderem benutzt, um beim NEWMAIL-Befehl neue Mails nach
 * einem bestimmten Datum anzuzeigen. (Nur fr Bulletins)
 * Filename: boxroot+"/info/"+bid
 */
typedef struct {
  char rubrik[9];		/* Rubrik */
  char mbx[9];			/* Verteiler */
  char sender[9];		/* Absender */
  time_t date;			/* Empfangszeitpunkt */
  long len;			/* Lnge des Files */
  int lt;			/* Lifetime */
  int nr;			/* Nummer des Datensatzes im Index-File */
  char bid[13];			/* Bulletin-ID */
  char subject[81];		/* Subject */
  unsigned long flags;		/* Flags - Siehe MAIL_XXX - Defines */
  unsigned long read;		/* Wie oft wurde diese Mail ausgelesen? */
  char art;			/* P = Usermail, B = Bulletin, A = ACK-Mail */
} s_check;


/* Format der Index-Files */
typedef struct {
  char mbx[9];			/* Verteiler */
  char sender[9];		/* Absender */
  time_t date;			/* Empfangszeitpunkt */
  long len;			/* Lnge des Files */
  int lt;			/* Lifetime */
  char bid[13];			/* Bulletin-ID */
  char subject[81];		/* Subject */
  unsigned long flags;		/* Flags - Siehe MAIL_XXX - Defines */
  unsigned long read;		/* Wie oft wurde diese Mail ausgelesen? */
} s_index;


typedef struct {
  char bid[13];
  int pending; /* 1 if the message has to be forwarded, 0 if already done */
  int locked;
} s_fwdqueue;



#endif /* __GLOBAL_H__ */







